@@ -4,17 +4,24 @@ from scipy.sparse.csgraph import connected_components
 
 
 def graph_connectivity(adata, label_key):
-    """"
-    Quantify how connected the subgraph corresponding to each batch cluster is.
-    Calculate per label: #cells_in_largest_connected_component/#all_cells
-    Final score: Average over labels
+    """Graph Connectivity
+
+    Quantify the connectivity of the subgraph per cell type label.
+    The final score is the average for all cell type labels :math:`C`, according to the equation:
+
+    .. math::
+
+        GC = \\frac {1} {|C|} \\sum_{c \\in C} \\frac {|{LCC(subgraph_c)}|} {|c|}
+
+    where :math:`|LCC(subgraph_c)|` stands for all cells in the largest connected component and :math:`|c|` stands for all cells of
+    cell type :math:`c`.
 
     :param adata: adata with computed neighborhood graph
     :param label_key: name in adata.obs containing the cell identity labels
     """
-    if 'neighbors' not in adata.uns:
+    if "neighbors" not in adata.uns:
         raise KeyError(
-            'Please compute the neighborhood graph before running this function!'
+            "Please compute the neighborhood graph before running this function!"
         )
 
     clust_res = []
@@ -22,8 +29,7 @@ def graph_connectivity(adata, label_key):
     for label in adata.obs[label_key].cat.categories:
         adata_sub = adata[adata.obs[label_key].isin([label])]
         _, labels = connected_components(
-            adata_sub.obsp['connectivities'],
-            connection='strong'
+            adata_sub.obsp["connectivities"], connection="strong"
         )
         tab = pd.value_counts(labels)
         clust_res.append(tab.max() / sum(tab))
